@@ -1,11 +1,11 @@
 ## ---- include = FALSE---------------------------------------------------------
 env_present <- slendr:::is_slendr_env_present()
-eval_chunk <- Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") == ""
+eval_chunk <- Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS"
 
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  dpi = 80,
+  dpi = 60,
   eval = eval_chunk
 )
 
