@@ -34,8 +34,8 @@ msprime(
 
 test_that("ape phylo conversion only works on simplified, coalesced trees (SLiM)", {
   ts1 <- ts_load(model = model, file = slim_ts)
-  suppressWarnings(ts2 <- ts_load(model = model, file = slim_ts, simplify = TRUE))
-  ts3 <- ts_load(model = model, file = slim_ts, recapitate = TRUE, Ne = 100, recombination_rate = 1e-8)
+  suppressWarnings(ts2 <- ts_load(model = model, file = slim_ts))
+  ts3 <- ts_load(model = model, file = slim_ts) %>% ts_recapitate(Ne = 100, recombination_rate = 1e-8)
 
   expect_error(
     ts_phylo(ts1, 0, mode = "index", quiet = TRUE),
@@ -53,17 +53,20 @@ test_that("ape phylo conversion only works on simplified, coalesced trees (SLiM)
 
 test_that("ape phylo conversion only works on simplified, coalesced trees (msprime)", {
   ts1 <- ts_load(model = model, file = msprime_ts)
-  suppressWarnings(ts2 <- ts_load(model = model, file = msprime_ts, simplify = TRUE))
-  suppressWarnings(ts3 <- ts_load(model = model, file = msprime_ts, recapitate = TRUE, Ne = 100, recombination_rate = 1e-8))
+  suppressWarnings(ts2 <- ts_load(model = model, file = msprime_ts) %>% ts_simplify())
+  suppressWarnings(ts3 <- ts_load(model = model, file = msprime_ts) %>% ts_recapitate(Ne = 100, recombination_rate = 1e-8))
 
   expect_s3_class(ts_phylo(ts1, 0, mode = "index", quiet = TRUE), "slendr_phylo")
   expect_s3_class(ts_phylo(ts2, 0, mode = "index", quiet = TRUE), "slendr_phylo")
   expect_s3_class(ts_phylo(ts3, 0, mode = "index", quiet = TRUE), "slendr_phylo")
 })
 
-ts1 <- ts_load(model = model, file = slim_ts, recapitate = TRUE, simplify = TRUE, mutate = TRUE,
-              Ne = 1000, recombination_rate = 1e-8, mutation_rate = 0.0000001)
-ts2 <- ts_load(model = model, file = msprime_ts, mutation_rate = 0.0000001)
+ts1 <- ts_load(model = model, file = slim_ts) %>%
+  ts_recapitate(Ne = 1000, recombination_rate = 1e-8) %>%
+  ts_simplify() %>%
+  ts_mutate(mutation_rate = 0.0000001)
+ts2 <- ts_load(model = model, file = msprime_ts) %>%
+  ts_mutate(mutation_rate = 0.0000001)
 
 test_that("ape phylo and tskit.Tree objects are created by ts_tree/ts_phylo (SLiM)", {
   t1 <- ts_tree(ts1, 0, mode = "index")
@@ -196,14 +199,14 @@ test_that("ts_phylo refuses a non-coalesced tree sequence", {
 })
 
 test_that("ts_phylo errors on a not-yet-simplified tree sequence", {
-  ts <- ts_load(model = model, file = slim_ts, recapitate = TRUE, Ne = 10, recombination_rate = 0)
+  ts <- ts_load(model = model, file = slim_ts) %>% ts_recapitate(Ne = 10, recombination_rate = 0)
   expect_error(ts_phylo(ts, 0, quiet = TRUE), "Please simplify your tree sequence")
-  ts <- ts_load(model = model, file = slim_ts, recapitate = TRUE, Ne = 10, recombination_rate = 0, simplify = TRUE)
+  ts <- ts_load(model = model, file = slim_ts) %>% ts_recapitate(Ne = 10, recombination_rate = 0) %>% ts_simplify()
   expect_s3_class(suppressWarnings(ts_phylo(ts, 0, quiet = TRUE)), "slendr_phylo")
 })
 
 test_that("ts_phylo gives a warning when a tree sequence is not fully spatial", {
-  ts <- ts_load(model = model, file = slim_ts, recapitate = TRUE, Ne = 10, recombination_rate = 0, simplify = TRUE)
+  ts <- ts_load(model = model, file = slim_ts) %>% ts_recapitate(Ne = 10, recombination_rate = 0) %>% ts_simplify()
   expect_warning(ts_phylo(ts, 0, quiet = TRUE),
                  "Not all nodes have a known spatial location.")
 
